find_clusters

Function find_clusters 

pub fn find_clusters<S: GraphStore + ?Sized>(
    store: &S,
    branch: &str,
    min_cluster_size: Option<usize>,
    limit: Option<usize>,
) -> Result<Vec<Cluster>>
Detect communities via synchronous label propagation, returning clusters of min_cluster_size or more members, ranked by size descending (ties broken by label).