pub async fn serve_daemon(repo_root: PathBuf) -> Result<()>
Own the embedded graph once and multiplex any number of local MCP clients. Client proxies send one mode byte before the newline-delimited MCP stream.