pub struct AstSearchParams {
pub kind: Option<String>,
pub is_async: Option<bool>,
pub visibility: Option<String>,
pub min_complexity: Option<u32>,
pub max_complexity: Option<u32>,
pub name_contains: Option<String>,
pub annotation: Option<String>,
pub limit: Option<usize>,
pub branch: Option<String>,
}Fields
kind: Option<String>NodeKind filter: “function”, “method”, “struct”, “trait”, “interface”, “enum”, “constant”, “type_alias”, “module”, etc. Omit for any kind.
is_async: Option<bool>When set, match only async (true) or only non-async (false) symbols.
visibility: Option<String>Visibility filter: “pub”, “pub_crate”, or “private”.
min_complexity: Option<u32>Inclusive lower bound on cyclomatic complexity. Symbols without a recorded complexity are excluded when this is set.
max_complexity: Option<u32>Inclusive upper bound on cyclomatic complexity.
name_contains: Option<String>Case-insensitive substring the symbol name must contain.
annotation: Option<String>Annotation/decorator name the symbol must carry (case-insensitive
substring): “Test” finds @Test, “route” finds @app.route,
“derive” finds #[derive(...)].
limit: Option<usize>Max results (default 30, capped at 200).
branch: Option<String>Trait Implementations
Sourceimpl Debug for AstSearchParams
impl Debug for AstSearchParams
Sourceimpl<'de> Deserialize<'de> for AstSearchParams
impl<'de> Deserialize<'de> for AstSearchParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AstSearchParams
impl JsonSchema for AstSearchParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AstSearchParams
impl RefUnwindSafe for AstSearchParams
impl Send for AstSearchParams
impl Sync for AstSearchParams
impl Unpin for AstSearchParams
impl UnsafeUnpin for AstSearchParams
impl UnwindSafe for AstSearchParams