pub struct FindCallersParams {
pub function_name: String,
pub depth: Option<u8>,
pub branch: Option<String>,
}Fields
function_name: StringName of the function/method to find callers of.
depth: Option<u8>How many hops to walk up the call graph (1–5, default 1). depth=1 returns direct callers only. depth=3 walks three levels.
branch: Option<String>Trait Implementations
Sourceimpl Debug for FindCallersParams
impl Debug for FindCallersParams
Sourceimpl<'de> Deserialize<'de> for FindCallersParams
impl<'de> Deserialize<'de> for FindCallersParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FindCallersParams
impl JsonSchema for FindCallersParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FindCallersParams
impl RefUnwindSafe for FindCallersParams
impl Send for FindCallersParams
impl Sync for FindCallersParams
impl Unpin for FindCallersParams
impl UnsafeUnpin for FindCallersParams
impl UnwindSafe for FindCallersParams