pub struct FindClustersParams {
pub min_cluster_size: Option<usize>,
pub limit: Option<usize>,
pub branch: Option<String>,
}Fields
min_cluster_size: Option<usize>Minimum members for a group to be reported as a cluster (default 3).
limit: Option<usize>Max clusters returned (default 20, capped at 100).
branch: Option<String>Trait Implementations
Sourceimpl Debug for FindClustersParams
impl Debug for FindClustersParams
Sourceimpl<'de> Deserialize<'de> for FindClustersParams
impl<'de> Deserialize<'de> for FindClustersParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FindClustersParams
impl JsonSchema for FindClustersParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FindClustersParams
impl RefUnwindSafe for FindClustersParams
impl Send for FindClustersParams
impl Sync for FindClustersParams
impl Unpin for FindClustersParams
impl UnsafeUnpin for FindClustersParams
impl UnwindSafe for FindClustersParams