pub struct FindImportersParams {
pub name: String,
pub branch: Option<String>,
}Fields
name: StringSymbol name to find importers of (the imported thing, unqualified).
branch: Option<String>Trait Implementations
Sourceimpl Debug for FindImportersParams
impl Debug for FindImportersParams
Sourceimpl<'de> Deserialize<'de> for FindImportersParams
impl<'de> Deserialize<'de> for FindImportersParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FindImportersParams
impl JsonSchema for FindImportersParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FindImportersParams
impl RefUnwindSafe for FindImportersParams
impl Send for FindImportersParams
impl Sync for FindImportersParams
impl Unpin for FindImportersParams
impl UnsafeUnpin for FindImportersParams
impl UnwindSafe for FindImportersParams