pub struct ListDefinitionsParams {
pub file: String,
pub branch: Option<String>,
}Fields
file: StringRepo-relative path to a source file.
branch: Option<String>Trait Implementations
Sourceimpl Debug for ListDefinitionsParams
impl Debug for ListDefinitionsParams
Sourceimpl<'de> Deserialize<'de> for ListDefinitionsParams
impl<'de> Deserialize<'de> for ListDefinitionsParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListDefinitionsParams
impl JsonSchema for ListDefinitionsParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListDefinitionsParams
impl RefUnwindSafe for ListDefinitionsParams
impl Send for ListDefinitionsParams
impl Sync for ListDefinitionsParams
impl Unpin for ListDefinitionsParams
impl UnsafeUnpin for ListDefinitionsParams
impl UnwindSafe for ListDefinitionsParams