pub struct ModuleDependenciesParams {
pub name: String,
pub branch: Option<String>,
}Fields
name: StringModule name (file stem, e.g. “tools” for tools.rs) to list dependencies of.
branch: Option<String>Trait Implementations
Sourceimpl Debug for ModuleDependenciesParams
impl Debug for ModuleDependenciesParams
Sourceimpl<'de> Deserialize<'de> for ModuleDependenciesParams
impl<'de> Deserialize<'de> for ModuleDependenciesParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModuleDependenciesParams
impl JsonSchema for ModuleDependenciesParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ModuleDependenciesParams
impl RefUnwindSafe for ModuleDependenciesParams
impl Send for ModuleDependenciesParams
impl Sync for ModuleDependenciesParams
impl Unpin for ModuleDependenciesParams
impl UnsafeUnpin for ModuleDependenciesParams
impl UnwindSafe for ModuleDependenciesParams