pub struct WikiSymbolParams {
pub name: String,
pub branch: Option<String>,
}Fields
name: StringSymbol to summarise (unqualified name).
branch: Option<String>Trait Implementations
Sourceimpl Debug for WikiSymbolParams
impl Debug for WikiSymbolParams
Sourceimpl<'de> Deserialize<'de> for WikiSymbolParams
impl<'de> Deserialize<'de> for WikiSymbolParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WikiSymbolParams
impl JsonSchema for WikiSymbolParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WikiSymbolParams
impl RefUnwindSafe for WikiSymbolParams
impl Send for WikiSymbolParams
impl Sync for WikiSymbolParams
impl Unpin for WikiSymbolParams
impl UnsafeUnpin for WikiSymbolParams
impl UnwindSafe for WikiSymbolParams