pub fn search<S: GraphStore + ?Sized>(
store: &S,
branch: &str,
query: &str,
limit: Option<usize>,
) -> Result<Vec<SearchHit>>Expand description
Run a fuzzy search across all nodes on branch.
Candidate set is built by querying the store for the whole query string AND
for each individual token (for multi-word / camelCase queries). Candidates
are deduplicated, scored with the multi-signal scorer, sorted by score
descending, and truncated to limit.