pub struct FindImplementorsParams {
pub trait_name: String,
pub branch: Option<String>,
}Fields
trait_name: StringTrait, interface, or abstract class name to find implementors of.
branch: Option<String>Trait Implementations
Sourceimpl Debug for FindImplementorsParams
impl Debug for FindImplementorsParams
Sourceimpl<'de> Deserialize<'de> for FindImplementorsParams
impl<'de> Deserialize<'de> for FindImplementorsParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FindImplementorsParams
impl JsonSchema for FindImplementorsParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FindImplementorsParams
impl RefUnwindSafe for FindImplementorsParams
impl Send for FindImplementorsParams
impl Sync for FindImplementorsParams
impl Unpin for FindImplementorsParams
impl UnsafeUnpin for FindImplementorsParams
impl UnwindSafe for FindImplementorsParams