pub struct ListSymbolsInRangeParams {
pub file: String,
pub start_line: u32,
pub end_line: u32,
pub branch: Option<String>,
}Fields
file: StringRepo-relative path to a source file.
start_line: u32Start line of the range (1-indexed, inclusive).
end_line: u32End line of the range (1-indexed, inclusive).
branch: Option<String>Trait Implementations
Sourceimpl Debug for ListSymbolsInRangeParams
impl Debug for ListSymbolsInRangeParams
Sourceimpl<'de> Deserialize<'de> for ListSymbolsInRangeParams
impl<'de> Deserialize<'de> for ListSymbolsInRangeParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListSymbolsInRangeParams
impl JsonSchema for ListSymbolsInRangeParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListSymbolsInRangeParams
impl RefUnwindSafe for ListSymbolsInRangeParams
impl Send for ListSymbolsInRangeParams
impl Sync for ListSymbolsInRangeParams
impl Unpin for ListSymbolsInRangeParams
impl UnsafeUnpin for ListSymbolsInRangeParams
impl UnwindSafe for ListSymbolsInRangeParams